Index: code/branches/cpp11_v2/src/libraries/core/ApplicationPaths.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/ApplicationPaths.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/ApplicationPaths.cc	(revision 10765)
@@ -84,5 +84,5 @@
         // get executable module
         TCHAR buffer[1024];
-        if (GetModuleFileName(NULL, buffer, 1024) == 0)
+        if (GetModuleFileName(nullptr, buffer, 1024) == 0)
             ThrowException(General, "Could not retrieve executable path.");
 
Index: code/branches/cpp11_v2/src/libraries/core/BaseObject.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/BaseObject.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/BaseObject.cc	(revision 10765)
@@ -205,5 +205,5 @@
             Template* link;
             assert(!(link = Template::getTemplate(temp->getLink())) || !link->isLink());
-            link = NULL;
+            link = nullptr;
         }
         else
Index: code/branches/cpp11_v2/src/libraries/core/BaseObject.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/BaseObject.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/BaseObject.h	(revision 10765)
@@ -265,5 +265,5 @@
             return this->weakPtr_;
         else
-            return NULL;
+            return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/libraries/core/ConfigurablePaths.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/ConfigurablePaths.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/ConfigurablePaths.cc	(revision 10765)
@@ -122,5 +122,5 @@
             char* userDataPathPtr(getenv("APPDATA"));
 #endif
-            if (userDataPathPtr == NULL)
+            if (userDataPathPtr == nullptr)
                 ThrowException(General, "Could not retrieve user data path.");
             bf::path userDataPath(userDataPathPtr);
Index: code/branches/cpp11_v2/src/libraries/core/Core.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/Core.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/Core.cc	(revision 10765)
@@ -95,24 +95,24 @@
 
     Core::Core(const std::string& cmdLine)
-        : applicationPaths_(NULL)
-        , configurablePaths_(NULL)
-        , dynLibManager_(NULL)
-        , signalHandler_(NULL)
-        , configFileManager_(NULL)
-        , languageInstance_(NULL)
-        , loaderInstance_(NULL)
-        , ioConsole_(NULL)
-        , tclBind_(NULL)
-        , tclThreadManager_(NULL)
-        , rootScope_(NULL)
-        , graphicsManager_(NULL)
-        , inputManager_(NULL)
-        , guiManager_(NULL)
-        , graphicsScope_(NULL)
+        : applicationPaths_(nullptr)
+        , configurablePaths_(nullptr)
+        , dynLibManager_(nullptr)
+        , signalHandler_(nullptr)
+        , configFileManager_(nullptr)
+        , languageInstance_(nullptr)
+        , loaderInstance_(nullptr)
+        , ioConsole_(nullptr)
+        , tclBind_(nullptr)
+        , tclThreadManager_(nullptr)
+        , rootScope_(nullptr)
+        , graphicsManager_(nullptr)
+        , inputManager_(nullptr)
+        , guiManager_(nullptr)
+        , graphicsScope_(nullptr)
         , bGraphicsLoaded_(false)
-        , staticInitHandler_(NULL)
-        , pluginManager_(NULL)
-        , rootModule_(NULL)
-        , config_(NULL)
+        , staticInitHandler_(nullptr)
+        , pluginManager_(nullptr)
+        , rootModule_(nullptr)
+        , config_(nullptr)
         , destructionHelper_(this)
     {
@@ -176,5 +176,5 @@
 
         // initialize root context
-        Context::setRootContext(new Context(NULL));
+        Context::setRootContext(new Context(nullptr));
 
         // Do this soon after the ConfigFileManager has been created to open up the
@@ -326,5 +326,5 @@
         module->deleteAllStaticallyInitializedInstances();
         this->dynLibManager_->unload(module->getDynLib());
-        module->setDynLib(NULL);
+        module->setDynLib(nullptr);
     }
 
@@ -471,5 +471,5 @@
         }
         // Process console events and status line
-        if (this->ioConsole_ != NULL)
+        if (this->ioConsole_ != nullptr)
             this->ioConsole_->preUpdate(time);
         // Process thread commands
Index: code/branches/cpp11_v2/src/libraries/core/CoreConfig.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/CoreConfig.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/CoreConfig.cc	(revision 10765)
@@ -137,10 +137,10 @@
     void CoreConfig::updateLastLevelTimestamp()
     {
-        ModifyConfigValue(lastLevelTimestamp_, set, static_cast<long long>(time(NULL)));
+        ModifyConfigValue(lastLevelTimestamp_, set, static_cast<long long>(time(nullptr)));
     }
 
     void CoreConfig::updateOgreConfigTimestamp()
     {
-        ModifyConfigValue(ogreConfigTimestamp_, set, static_cast<long long>(time(NULL)));
+        ModifyConfigValue(ogreConfigTimestamp_, set, static_cast<long long>(time(nullptr)));
     }
 
Index: code/branches/cpp11_v2/src/libraries/core/CoreIncludes.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/CoreIncludes.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/CoreIncludes.h	(revision 10765)
@@ -120,5 +120,5 @@
 */
 #define RegisterAbstractClass(ClassName) \
-    RegisterClassWithFactory(ClassName, static_cast<ClassFactory<ClassName>*>(NULL), false)
+    RegisterClassWithFactory(ClassName, static_cast<ClassFactory<ClassName>*>(nullptr), false)
 
 /**
Index: code/branches/cpp11_v2/src/libraries/core/GUIManager.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/GUIManager.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/GUIManager.cc	(revision 10765)
@@ -268,18 +268,18 @@
     */
     GUIManager::GUIManager(const std::pair<int, int>& mousePosition)
-        : guiRenderer_(NULL)
-        , resourceProvider_(NULL)
+        : guiRenderer_(nullptr)
+        , resourceProvider_(nullptr)
 #ifndef ORXONOX_OLD_CEGUI
-        , rqListener_(NULL)
-        , imageCodec_(NULL)
-#endif
-        , luaState_(NULL)
-        , scriptModule_(NULL)
-        , guiSystem_(NULL)
-        , ceguiLogger_(NULL)
-        , rootWindow_(NULL)
-        , hudRootWindow_(NULL)
-        , menuRootWindow_(NULL)
-        , camera_(NULL)
+        , rqListener_(nullptr)
+        , imageCodec_(nullptr)
+#endif
+        , luaState_(nullptr)
+        , scriptModule_(nullptr)
+        , guiSystem_(nullptr)
+        , ceguiLogger_(nullptr)
+        , rootWindow_(nullptr)
+        , hudRootWindow_(nullptr)
+        , menuRootWindow_(nullptr)
+        , camera_(nullptr)
         , destructionHelper_(this)
     {
@@ -467,12 +467,12 @@
     {
 #ifdef ORXONOX_OLD_CEGUI
-        if (camera == NULL)
+        if (camera == nullptr)
             this->guiRenderer_->setTargetSceneManager(0);
         else
             this->guiRenderer_->setTargetSceneManager(camera->getSceneManager());
 #else
-        if (camera_ != NULL && camera_->getSceneManager() != NULL)
+        if (camera_ != nullptr && camera_->getSceneManager() != nullptr)
             camera_->getSceneManager()->removeRenderQueueListener(rqListener_);
-        if (camera != NULL && camera->getSceneManager() != NULL)
+        if (camera != nullptr && camera->getSceneManager() != nullptr)
             camera->getSceneManager()->addRenderQueueListener(rqListener_);
 #endif
@@ -876,5 +876,5 @@
             return;
 
-        CEGUI::Font* font = NULL;
+        CEGUI::Font* font = nullptr;
         CEGUI::XMLAttributes xmlAttributes;
 
@@ -892,5 +892,5 @@
 
         font = CEGUI::FontManager::getSingleton().createFont("FreeType", xmlAttributes);
-        if(font != NULL)
+        if(font != nullptr)
             font->load();
 #else
Index: code/branches/cpp11_v2/src/libraries/core/Game.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/Game.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/Game.cc	(revision 10765)
@@ -77,9 +77,9 @@
 
     Game::Game(const std::string& cmdLine)
-        : gameClock_(NULL)
-        , core_(NULL)
+        : gameClock_(nullptr)
+        , core_(nullptr)
         , bChangingState_(false)
         , bAbort_(false)
-        , config_(NULL)
+        , config_(nullptr)
         , destructionHelper_(this)
     {
@@ -398,5 +398,5 @@
             // Check parent and all its grand parents
             shared_ptr<GameStateTreeNode> currentNode = lastRequestedNode;
-            while (currentNode != NULL)
+            while (currentNode != nullptr)
             {
                 if (currentNode->name_ == name)
@@ -405,5 +405,5 @@
                 requestedNodes.push_back(currentNode);
             }
-            if (currentNode == NULL)
+            if (currentNode == nullptr)
                 requestedNodes.clear();
         }
Index: code/branches/cpp11_v2/src/libraries/core/GraphicsManager.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/GraphicsManager.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/GraphicsManager.cc	(revision 10765)
@@ -178,5 +178,5 @@
     void GraphicsManager::upgradeToGraphics()
     {
-        if (renderWindow_ != NULL)
+        if (renderWindow_ != nullptr)
             return;
 
Index: code/branches/cpp11_v2/src/libraries/core/GraphicsManager.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/GraphicsManager.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/GraphicsManager.h	(revision 10765)
@@ -96,5 +96,5 @@
         void loadDebugOverlay();
         void unloadDebugOverlay();
-        bool rendererLoaded() const { return renderWindow_ != NULL; }
+        bool rendererLoaded() const { return renderWindow_ != nullptr; }
 
         void setCamera(Ogre::Camera* camera);
Index: code/branches/cpp11_v2/src/libraries/core/Loader.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/Loader.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/Loader.cc	(revision 10765)
@@ -89,5 +89,5 @@
         {
             shared_ptr<ResourceInfo> info = Resource::getInfo(file->getFilename());
-            if (info == NULL)
+            if (info == nullptr)
             {
                 orxout(user_error, context::loader) << "Could not find XML file '" << file->getFilename() << "'." << endl;
Index: code/branches/cpp11_v2/src/libraries/core/LuaState.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/LuaState.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/LuaState.cc	(revision 10765)
@@ -48,5 +48,5 @@
     LuaState::LuaState()
         : bIsRunning_(false)
-        , includeParseFunction_(NULL)
+        , includeParseFunction_(nullptr)
     {
         // Create new lua state and configure it
@@ -84,5 +84,5 @@
         shared_ptr<ResourceInfo> sourceInfo = Resource::getInfo(sourceFileInfo_->path + filename);
         // Continue search in root directories
-        if (sourceInfo == NULL && !sourceFileInfo_->path.empty())
+        if (sourceInfo == nullptr && !sourceFileInfo_->path.empty())
             sourceInfo = Resource::getInfo(filename);
         return sourceInfo;
@@ -92,5 +92,5 @@
     {
         shared_ptr<ResourceInfo> sourceInfo = this->getFileInfo(filename);
-        if (sourceInfo != NULL)
+        if (sourceInfo != nullptr)
             return this->includeString(Resource::open(sourceInfo)->getAsString(), sourceInfo);
         else
@@ -105,10 +105,10 @@
         // Parse string with provided include parser (otherwise don't preparse at all)
         std::string luaInput;
-        if (includeParseFunction_ != NULL)
+        if (includeParseFunction_ != nullptr)
             luaInput = (*includeParseFunction_)(code);
         else
             luaInput = code;
 
-        if (sourceFileInfo != NULL)
+        if (sourceFileInfo != nullptr)
         {
             // Also fill a map with the actual source code. This is just for the include* commands
@@ -119,8 +119,8 @@
         bool returnValue = this->doString(luaInput, sourceFileInfo);
 
-        if (sourceFileInfo != NULL)
+        if (sourceFileInfo != nullptr)
         {
             // Delete source code entry
-            if (sourceFileInfo != NULL)
+            if (sourceFileInfo != nullptr)
                 this->sourceCodeMap_.erase(sourceFileInfo->filename);
         }
@@ -132,5 +132,5 @@
     {
         shared_ptr<ResourceInfo> sourceInfo = this->getFileInfo(filename);
-        if (sourceInfo != NULL)
+        if (sourceInfo != nullptr)
             return this->doString(Resource::open(sourceInfo)->getAsString(), sourceInfo);
         else
@@ -146,9 +146,9 @@
         shared_ptr<ResourceInfo> oldSourceFileInfo = sourceFileInfo_;
         // Only override if sourceFileInfo provides useful information
-        if (sourceFileInfo != NULL)
+        if (sourceFileInfo != nullptr)
             sourceFileInfo_ = sourceFileInfo;
 
         std::string chunkname;
-        if (sourceFileInfo != NULL)
+        if (sourceFileInfo != nullptr)
         {
             // Provide lua_load with the filename for debug purposes
@@ -286,5 +286,5 @@
     {
         shared_ptr<ResourceInfo> info = this->getFileInfo(filename);
-        if (info == NULL)
+        if (info == nullptr)
             return false;
         else
@@ -301,5 +301,5 @@
             return it->second;
         shared_ptr<ResourceInfo> info = Resource::getInfo(filename);
-        if (info == NULL)
+        if (info == nullptr)
             return "";
         else
Index: code/branches/cpp11_v2/src/libraries/core/Resource.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/Resource.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/Resource.cc	(revision 10765)
@@ -102,7 +102,7 @@
                 ptr->size = it->uncompressedSize;
 #if OGRE_VERSION >= 0x010800
-                if (dynamic_cast<const Ogre::FileSystemArchive*>(it->archive) != NULL)
+                if (dynamic_cast<const Ogre::FileSystemArchive*>(it->archive) != nullptr)
 #else
-                if (dynamic_cast<Ogre::FileSystemArchive*>(it->archive) != NULL)
+                if (dynamic_cast<Ogre::FileSystemArchive*>(it->archive) != nullptr)
 #endif
                 {
Index: code/branches/cpp11_v2/src/libraries/core/class/Identifiable.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/class/Identifiable.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/class/Identifiable.h	(revision 10765)
@@ -98,5 +98,5 @@
                 registered in the class hierarchy.
             @return
-                Returns NULL if the no pointer was found.
+                Returns nullptr if the no pointer was found.
             */
             ORX_FORCEINLINE void* getDerivedPointer(unsigned int classID)
@@ -107,5 +107,5 @@
                         return this->objectPointers_[i].second;
                 }
-                return NULL;
+                return nullptr;
             }
 
Index: code/branches/cpp11_v2/src/libraries/core/class/Identifier.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/class/Identifier.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/class/Identifier.h	(revision 10765)
@@ -279,5 +279,5 @@
             ClassIdentifier(const std::string& name, Factory* factory, bool bLoadable) : Identifier(name, factory, bLoadable)
             {
-                OrxVerify(ClassIdentifier<T>::classIdentifier_s == NULL, "Assertion failed in ClassIdentifier of type " << typeid(T).name());
+                OrxVerify(ClassIdentifier<T>::classIdentifier_s == nullptr, "Assertion failed in ClassIdentifier of type " << typeid(T).name());
                 ClassIdentifier<T>::classIdentifier_s = this;
 
@@ -334,8 +334,8 @@
     /*static*/ inline ClassIdentifier<T>* ClassIdentifier<T>::getIdentifier()
     {
-        if (ClassIdentifier<T>::classIdentifier_s == NULL)
+        if (ClassIdentifier<T>::classIdentifier_s == nullptr)
             ClassIdentifier<T>::classIdentifier_s = (ClassIdentifier<T>*) IdentifierManager::getInstance().getIdentifierByTypeInfo(typeid(T));
 
-        OrxVerify(ClassIdentifier<T>::classIdentifier_s != NULL, "Did you forget to register the class of type " << typeid(T).name() << "?");
+        OrxVerify(ClassIdentifier<T>::classIdentifier_s != nullptr, "Did you forget to register the class of type " << typeid(T).name() << "?");
         return ClassIdentifier<T>::classIdentifier_s;
     }
@@ -451,5 +451,5 @@
     void ClassIdentifier<T>::updateConfigValues(bool updateChildren) const
     {
-        this->updateConfigValues(updateChildren, static_cast<T*>(NULL));
+        this->updateConfigValues(updateChildren, static_cast<T*>(nullptr));
     }
 
@@ -483,7 +483,7 @@
         registered in the class hierarchy.
     @return
-        Returns NULL if the cast is not possible
+        Returns nullptr if the cast is not possible
     @note
-        In case of NULL return (and using MSVC), a dynamic_cast might still be possible if
+        In case of nullptr return (and using MSVC), a dynamic_cast might still be possible if
         a class forgot to register its objects.
         Also note that the function is implemented differently for GCC/MSVC.
@@ -494,8 +494,8 @@
 #ifdef ORXONOX_COMPILER_MSVC
         typedef Loki::TypeTraits<typename Loki::TypeTraits<T>::PointeeType>::NonConstType ClassType;
-        if (source != NULL)
+        if (source != nullptr)
             return source->template getDerivedPointer<ClassType>(ClassIdentifier<ClassType>::getIdentifier()->getClassID());
         else
-            return NULL;
+            return nullptr;
 #else
         return dynamic_cast<T>(source);
Index: code/branches/cpp11_v2/src/libraries/core/class/IdentifierManager.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/class/IdentifierManager.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/class/IdentifierManager.cc	(revision 10765)
@@ -49,5 +49,5 @@
     {
         this->hierarchyCreatingCounter_s = 0;
-        this->recordTraceForIdentifier_ = NULL;
+        this->recordTraceForIdentifier_ = nullptr;
     }
 
@@ -92,5 +92,5 @@
         // iterate over all identifiers, create one instance of each class and initialize the identifiers
         {
-            Context temporaryContext(NULL);
+            Context temporaryContext(nullptr);
             for (std::set<Identifier*>::const_iterator it = this->identifiers_.begin(); it != this->identifiers_.end(); ++it)
             {
@@ -108,5 +108,5 @@
                     Identifiable* temp = identifier->fabricate(&temporaryContext);
 
-                    this->recordTraceForIdentifier_ = NULL;
+                    this->recordTraceForIdentifier_ = nullptr;
 
                     if (temp->getIdentifier() != identifier)
@@ -149,5 +149,5 @@
 
         // for all initialized identifiers, check if a sample instance behaves as expected according to the class hierarchy
-        Context temporaryContext(NULL);
+        Context temporaryContext(nullptr);
         for (std::set<Identifier*>::const_iterator it1 = initializedIdentifiers.begin(); it1 != initializedIdentifiers.end(); ++it1)
         {
Index: code/branches/cpp11_v2/src/libraries/core/class/SubclassIdentifier.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/class/SubclassIdentifier.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/class/SubclassIdentifier.h	(revision 10765)
@@ -127,5 +127,5 @@
                     else
                     {
-                        orxout(internal_error) << "Can't assign NULL identifier" << endl;
+                        orxout(internal_error) << "Can't assign nullptr identifier" << endl;
                     }
                 }
Index: code/branches/cpp11_v2/src/libraries/core/command/CommandEvaluation.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/CommandEvaluation.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/CommandEvaluation.cc	(revision 10765)
@@ -119,5 +119,5 @@
     /**
         @brief Executes the command which was evaluated by this object and returns its return-value.
-        @param error A pointer to an integer (or NULL) which will be used to write error codes to (see @ref CommandExecutorErrorCodes "CommandExecutor error codes")
+        @param error A pointer to an integer (or nullptr) which will be used to write error codes to (see @ref CommandExecutorErrorCodes "CommandExecutor error codes")
         @return Returns the result of the command (or MultiType::Null if there is no return value)
     */
Index: code/branches/cpp11_v2/src/libraries/core/command/CommandEvaluation.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/CommandEvaluation.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/CommandEvaluation.h	(revision 10765)
@@ -137,5 +137,5 @@
             static std::string getCommonBegin(const ArgumentCompletionList& list);
 
-            const ConsoleCommand* execCommand_;             ///< The command that will be executed (can be NULL if the command is not valid)
+            const ConsoleCommand* execCommand_;             ///< The command that will be executed (can be nullptr if the command is not valid)
             const ConsoleCommand* hintCommand_;             ///< The command that is used to display hints and argument lists (can be different to execCommand_ in some cases)
             SubString tokens_;                              ///< The single words of the command string, split into tokens
Index: code/branches/cpp11_v2/src/libraries/core/command/CommandExecutor.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/CommandExecutor.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/CommandExecutor.cc	(revision 10765)
@@ -81,5 +81,5 @@
         @brief Executes a command and returns its return-value.
         @param command A string containing the command
-        @param error A pointer to a value (or NULL) where the error-code should be written to (see @ref CommandExecutorErrorCodes "error codes")
+        @param error A pointer to a value (or nullptr) where the error-code should be written to (see @ref CommandExecutorErrorCodes "error codes")
         @param useTcl If true, the command is passed to tcl (see TclBind)
         @return Returns the return-value of the command (if any - MultiType::Null otherwise)
@@ -127,5 +127,5 @@
         @brief Executes a command and returns its return-value as string.
         @param command A string containing the command
-        @param error A pointer to a value (or NULL) where the error-code should be written to (see @ref CommandExecutorErrorCodes "error codes")
+        @param error A pointer to a value (or nullptr) where the error-code should be written to (see @ref CommandExecutorErrorCodes "error codes")
         @param useTcl If true, the command is passed to tcl (see TclBind)
         @return Returns the return-value of the command converted to a string (or "" if there's no return value)
Index: code/branches/cpp11_v2/src/libraries/core/command/ConsoleCommand.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/ConsoleCommand.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/ConsoleCommand.cc	(revision 10765)
@@ -348,5 +348,5 @@
 
     /**
-        @brief Sets the functor to NULL (which also deactivates the command).
+        @brief Sets the functor to nullptr (which also deactivates the command).
     */
     void ConsoleCommand::resetFunction()
Index: code/branches/cpp11_v2/src/libraries/core/command/ConsoleCommand.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/ConsoleCommand.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/ConsoleCommand.h	(revision 10765)
@@ -195,5 +195,5 @@
                         { if (this->command_) { this->command_->popFunction(); } return *this; }
 
-                    /// Sets the current function-pointer to NULL, which also deactivates the command.
+                    /// Sets the current function-pointer to nullptr, which also deactivates the command.
                     inline ConsoleCommandManipulator& resetFunction()
                         { if (this->command_) { this->command_->resetFunction(); } return *this; }
@@ -205,5 +205,5 @@
                     inline ConsoleCommandManipulator& pushObject(void* object)
                         { if (this->command_) { this->command_->pushObject(object); } return *this; }
-                    /// Removes the current object from the object-stack and restores the old object (or NULL if there's no object left on the stack).
+                    /// Removes the current object from the object-stack and restores the old object (or nullptr if there's no object left on the stack).
                     inline ConsoleCommandManipulator& popObject()
                         { if (this->command_) { this->command_->popObject(); } return *this; }
Index: code/branches/cpp11_v2/src/libraries/core/command/ConsoleCommandIncludes.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/ConsoleCommandIncludes.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/ConsoleCommandIncludes.h	(revision 10765)
@@ -331,5 +331,5 @@
         @brief Returns a manipulator for a command with the given name.
 
-        @note If the command doesn't exist, the manipulator contains a NULL pointer to the command,
+        @note If the command doesn't exist, the manipulator contains a nullptr to the command,
         but it can still be used without checks, because all functions of ConsoleCommandManipulator
         check internally if the command exists.
@@ -340,5 +340,5 @@
         @brief Returns a manipulator for a command with the given group and name.
 
-        @note If the command doesn't exist, the manipulator contains a NULL pointer to the command,
+        @note If the command doesn't exist, the manipulator contains a nullptr to the command,
         but it can still be used without checks, because all functions of ConsoleCommandManipulator
         check internally if the command exists.
Index: code/branches/cpp11_v2/src/libraries/core/command/Executor.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/Executor.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/Executor.cc	(revision 10765)
@@ -76,5 +76,5 @@
         @brief Calls the wrapped function with arguments that are passed in a string.
         @param arguments The arguments that should be passed to the function, separated by @a delimiter
-        @param error A pointer to a variable (or NULL) that is used to store the error code (see @ref CommandExecutorErrorCodes "CommandExecutor error codes")
+        @param error A pointer to a variable (or nullptr) that is used to store the error code (see @ref CommandExecutorErrorCodes "CommandExecutor error codes")
         @param delimiter The delimiter that is used to separate the arguments in the string @a arguments
         @param bPrintError If true, errors are printed to the console if the function couldn't be executed with the given arguments
@@ -89,5 +89,5 @@
         @brief Calls the wrapped function with arguments that are passed as tokens in a SubString
         @param arguments The arguments that should be passed to the function
-        @param error A pointer to a variable (or NULL) that is used to store the error code (see @ref CommandExecutorErrorCodes "CommandExecutor error codes")
+        @param error A pointer to a variable (or nullptr) that is used to store the error code (see @ref CommandExecutorErrorCodes "CommandExecutor error codes")
         @param delimiter The delimiter that was used to separate the arguments in the SubString @a arguments (used to join the surplus arguments)
         @param bPrintError If true, errors are printed to the console if the function couldn't be executed with the given arguments
@@ -127,5 +127,5 @@
         @param arguments The arguments that should be converted
         @param arg An array of MultiType where the converted arguments will be stored
-        @param error A pointer to a variable (or NULL) that is used to store the error code (see @ref CommandExecutorErrorCodes "CommandExecutor error codes")
+        @param error A pointer to a variable (or nullptr) that is used to store the error code (see @ref CommandExecutorErrorCodes "CommandExecutor error codes")
         @param delimiter The delimiter that was used to separate the arguments in the SubString @a arguments (used to join the surplus arguments)
         @return Returns the number of evaluated arguments
Index: code/branches/cpp11_v2/src/libraries/core/command/IOConsolePOSIX.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/IOConsolePOSIX.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/IOConsolePOSIX.cc	(revision 10765)
@@ -44,5 +44,5 @@
 namespace orxonox
 {
-    IOConsole* IOConsole::singletonPtr_s = NULL;
+    IOConsole* IOConsole::singletonPtr_s = nullptr;
 
     namespace EscapeMode
@@ -353,9 +353,9 @@
         const char* s;
         if (!this->terminalWidth_ && (s = getenv("COLUMNS")))
-            this->terminalWidth_  = strtol(s, NULL, 10);
+            this->terminalWidth_  = strtol(s, nullptr, 10);
         if (!this->terminalWidth_)
             this->terminalWidth_ = 80;
         if (!this->terminalHeight_ && (s = getenv("LINES")))
-            this->terminalHeight_ = strtol(s, NULL, 10);
+            this->terminalHeight_ = strtol(s, nullptr, 10);
         if (!this->terminalHeight_)
             this->terminalHeight_ = 24;
Index: code/branches/cpp11_v2/src/libraries/core/command/IOConsoleWindows.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/IOConsoleWindows.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/IOConsoleWindows.cc	(revision 10765)
@@ -41,5 +41,5 @@
 namespace orxonox
 {
-    IOConsole* IOConsole::singletonPtr_s = NULL;
+    IOConsole* IOConsole::singletonPtr_s = nullptr;
 
     //! Redirects std::cout, creates the corresponding Shell and changes the terminal mode
@@ -300,5 +300,5 @@
                 this->terminalWidth_ - 1, this->inputLineRow_ + this->inputLineHeight_ + this->statusLines_ - 1);
             this->inputLineRow_ += linesDown;
-            ScrollConsoleScreenBuffer(stdOutHandle_, &oldRect, NULL, makeCOORD(0, this->inputLineRow_), &fillChar);
+            ScrollConsoleScreenBuffer(stdOutHandle_, &oldRect, nullptr, makeCOORD(0, this->inputLineRow_), &fillChar);
             // Move cursor down to the new bottom so the user can see the status lines
             COORD pos = makeCOORD(0, this->inputLineRow_ + this->inputLineHeight_ - 1 + this->statusLines_);
@@ -312,5 +312,5 @@
             // Scroll output up
             SMALL_RECT oldRect = makeSMALL_RECT(0, lines - linesDown, this->terminalWidth_ - 1, this->inputLineRow_ - 1);
-            ScrollConsoleScreenBuffer(stdOutHandle_, &oldRect, NULL, makeCOORD(0, 0), &fillChar);
+            ScrollConsoleScreenBuffer(stdOutHandle_, &oldRect, nullptr, makeCOORD(0, 0), &fillChar);
         }
     }
@@ -360,5 +360,5 @@
             SMALL_RECT oldRect = makeSMALL_RECT(0, statusLineRow, this->terminalWidth_ - 1, statusLineRow + this->statusLines_);
             CHAR_INFO fillChar = {{' '}, FOREGROUND_BLUE | FOREGROUND_GREEN | FOREGROUND_RED};
-            ScrollConsoleScreenBuffer(stdOutHandle_, &oldRect, NULL, makeCOORD(0, statusLineRow + newLines), &fillChar);
+            ScrollConsoleScreenBuffer(stdOutHandle_, &oldRect, nullptr, makeCOORD(0, statusLineRow + newLines), &fillChar);
             // Clear potential leftovers
             if (-newLines - this->statusLines_ > 0)
Index: code/branches/cpp11_v2/src/libraries/core/command/TclBind.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/TclBind.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/TclBind.cc	(revision 10765)
@@ -228,5 +228,5 @@
         @brief Executes Tcl-code and returns the return-value.
         @param tclcode A string that contains Tcl-code
-        @param error A pointer to an integer (or NULL) that is used to write an error-code (see @ref CommandExecutorErrorCodes "CommandExecutor error codes")
+        @param error A pointer to an integer (or nullptr) that is used to write an error-code (see @ref CommandExecutorErrorCodes "CommandExecutor error codes")
         @return Returns the return-value of the executed code (or an empty string if there's no return-value)
     */
Index: code/branches/cpp11_v2/src/libraries/core/config/ConfigFile.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/config/ConfigFile.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/config/ConfigFile.cc	(revision 10765)
@@ -275,5 +275,5 @@
 
     /**
-        @brief Returns a pointer to the section with given name (or NULL if the section doesn't exist).
+        @brief Returns a pointer to the section with given name (or nullptr if the section doesn't exist).
     */
     ConfigFileSection* ConfigFile::getSection(const std::string& section) const
@@ -282,5 +282,5 @@
             if ((*it)->getName() == section)
                 return (*it);
-        return NULL;
+        return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/libraries/core/config/ConfigFileSection.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/config/ConfigFileSection.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/config/ConfigFileSection.cc	(revision 10765)
@@ -99,5 +99,5 @@
 
     /**
-        @brief Returns the entry with given name (or NULL if it doesn't exist).
+        @brief Returns the entry with given name (or nullptr if it doesn't exist).
 
         @param name     The name of the entry
@@ -110,9 +110,9 @@
                 return *it;
         }
-        return NULL;
+        return nullptr;
     }
 
     /**
-        @brief Returns the entry of a vector element with given name and index (or NULL if it doesn't exist).
+        @brief Returns the entry of a vector element with given name and index (or nullptr if it doesn't exist).
 
         @param name     The name of the vector
@@ -126,5 +126,5 @@
                 return *it;
         }
-        return NULL;
+        return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/libraries/core/config/ConfigValueContainer.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/config/ConfigValueContainer.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/config/ConfigValueContainer.h	(revision 10765)
@@ -223,5 +223,5 @@
             inline const std::string& getSectionName() const
                 { return this->sectionname_; }
-            /// Returns the associated identifier (can be NULL).
+            /// Returns the associated identifier (can be nullptr).
             inline Identifier* getIdentifier() const
                 { return this->identifier_; }
Index: code/branches/cpp11_v2/src/libraries/core/config/SettingsConfigFile.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/config/SettingsConfigFile.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/config/SettingsConfigFile.cc	(revision 10765)
@@ -106,5 +106,5 @@
     void SettingsConfigFile::addConfigValueContainer(ConfigValueContainer* container)
     {
-        if (container == NULL)
+        if (container == nullptr)
             return;
         std::pair<std::string, ConfigValueContainer*> second(getLowercase(container->getName()), container);
@@ -118,5 +118,5 @@
     void SettingsConfigFile::removeConfigValueContainer(ConfigValueContainer* container)
     {
-        if (container == NULL)
+        if (container == nullptr)
             return;
         const std::string& sectionLC = getLowercase(container->getSectionName());
@@ -269,5 +269,5 @@
             {
                 std::string value;
-                it->second.second->getValue<std::string, void>(&value, NULL);
+                it->second.second->getValue<std::string, void>(&value, nullptr);
                 return value;
             }
Index: code/branches/cpp11_v2/src/libraries/core/input/InputManager.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/input/InputManager.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/input/InputManager.cc	(revision 10765)
@@ -210,5 +210,5 @@
         catch (const std::exception& ex)
         {
-            oisInputManager_ = NULL;
+            oisInputManager_ = nullptr;
             internalState_ |= Bad;
             ThrowException(InitialisationFailed, "Could not initialise the input system: " << ex.what());
@@ -312,5 +312,5 @@
         BOOST_FOREACH(InputDevice*& device, devices_)
         {
-            if (device == NULL)
+            if (device == nullptr)
                 continue;
             const std::string& className = device->getClassName();
@@ -321,5 +321,5 @@
         devices_.resize(InputDeviceEnumerator::FirstJoyStick);
 
-        assert(oisInputManager_ != NULL);
+        assert(oisInputManager_ != nullptr);
         try
         {
@@ -331,5 +331,5 @@
                                                    << "Potential resource leak!" << endl;
         }
-        oisInputManager_ = NULL;
+        oisInputManager_ = nullptr;
 
         internalState_ |= Bad;
@@ -388,5 +388,5 @@
         // No event gets triggered here yet!
         BOOST_FOREACH(InputDevice* device, devices_)
-            if (device != NULL)
+            if (device != nullptr)
                 device->update(time);
 
@@ -419,5 +419,5 @@
         for (unsigned int i = 0; i < devices_.size(); ++i)
         {
-            if (devices_[i] == NULL)
+            if (devices_[i] == nullptr)
                 continue;
             std::vector<InputState*>& states = devices_[i]->getStateListRef();
@@ -439,5 +439,5 @@
         std::set<InputState*> tempSet;
         for (unsigned int i = 0; i < devices_.size(); ++i)
-            if (devices_[i] != NULL)
+            if (devices_[i] != nullptr)
                 for (unsigned int iState = 0; iState < devices_[i]->getStateListRef().size(); ++iState)
                     tempSet.insert(devices_[i]->getStateListRef()[iState]);
@@ -467,5 +467,5 @@
     {
         BOOST_FOREACH(InputDevice* device, devices_)
-            if (device != NULL)
+            if (device != nullptr)
                 device->clearBuffers();
     }
@@ -477,5 +477,5 @@
 
         BOOST_FOREACH(InputDevice* device, devices_)
-            if (device != NULL)
+            if (device != nullptr)
                 device->startCalibration();
 
@@ -488,5 +488,5 @@
     {
         BOOST_FOREACH(InputDevice* device, devices_)
-            if (device != NULL)
+            if (device != nullptr)
                 device->stopCalibration();
 
@@ -509,5 +509,5 @@
     {
         Mouse* mouse = static_cast<Mouse*>(devices_[InputDeviceEnumerator::Mouse]);
-        if (mouse != NULL)
+        if (mouse != nullptr)
         {
             const OIS::MouseState state = mouse->getOISDevice()->getMouseState();
Index: code/branches/cpp11_v2/src/libraries/core/input/InputManager.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/input/InputManager.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/input/InputManager.h	(revision 10765)
@@ -134,5 +134,5 @@
             Returns a pointer to a InputState referenced by name.
         @return
-            Returns NULL if state was not found.
+            Returns nullptr if state was not found.
         */
         InputState* getState(const std::string& name);
Index: code/branches/cpp11_v2/src/libraries/core/input/InputState.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/input/InputState.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/input/InputState.cc	(revision 10765)
@@ -49,5 +49,5 @@
             priority_ = 0;
 
-        handlers_.resize(InputDeviceEnumerator::FirstJoyStick + this->getJoyStickList().size(), NULL);
+        handlers_.resize(InputDeviceEnumerator::FirstJoyStick + this->getJoyStickList().size(), nullptr);
     }
 
@@ -55,5 +55,5 @@
     {
         if (device < handlers_.size())
-            return handlers_[device] != NULL;
+            return handlers_[device] != nullptr;
         else
             return false;
@@ -64,5 +64,5 @@
     {
         unsigned int oldSize = handlers_.size();
-        handlers_.resize(InputDeviceEnumerator::FirstJoyStick + joyStickList.size(), NULL);
+        handlers_.resize(InputDeviceEnumerator::FirstJoyStick + joyStickList.size(), nullptr);
 
         for (unsigned int i = oldSize; i < handlers_.size(); ++i)
Index: code/branches/cpp11_v2/src/libraries/core/input/InputState.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/input/InputState.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/input/InputState.h	(revision 10765)
@@ -179,5 +179,5 @@
     {
         for (unsigned int i = 0; i < handlers_.size(); ++i)
-            if (handlers_[i] != NULL)
+            if (handlers_[i] != nullptr)
                 INPUT_STATE_PUSH_CALL(i, allDevicesUpdated, dt);
     }
@@ -188,15 +188,15 @@
         {
         case InputDeviceEnumerator::Keyboard:
-            if (handlers_[keyboardIndex_s] != NULL)
+            if (handlers_[keyboardIndex_s] != nullptr)
                 INPUT_STATE_PUSH_CALL(keyboardIndex_s, keyboardUpdated, dt);
             break;
 
         case InputDeviceEnumerator::Mouse:
-            if (handlers_[mouseIndex_s] != NULL)
+            if (handlers_[mouseIndex_s] != nullptr)
                 INPUT_STATE_PUSH_CALL(mouseIndex_s, mouseUpdated, dt);
             break;
 
         default: // joy sticks
-            if (handlers_[device] != NULL)
+            if (handlers_[device] != nullptr)
                 INPUT_STATE_PUSH_CALL(device, joyStickUpdated, device - firstJoyStickIndex_s, dt);
             break;
@@ -208,5 +208,5 @@
     {
         assert(device < handlers_.size());
-        if (handlers_[device] != NULL)
+        if (handlers_[device] != nullptr)
         {
             // We have to store the function pointer to tell the compiler about its actual type because of overloading
@@ -218,5 +218,5 @@
     ORX_FORCEINLINE void InputState::mouseMoved(IntVector2 abs, IntVector2 rel, IntVector2 clippingSize)
     {
-        if (handlers_[mouseIndex_s] != NULL)
+        if (handlers_[mouseIndex_s] != nullptr)
             INPUT_STATE_PUSH_CALL(mouseIndex_s, mouseMoved, abs, rel, clippingSize);
     }
@@ -224,5 +224,5 @@
     ORX_FORCEINLINE void InputState::mouseScrolled(int abs, int rel)
     {
-        if (handlers_[mouseIndex_s] != NULL)
+        if (handlers_[mouseIndex_s] != nullptr)
             INPUT_STATE_PUSH_CALL(mouseIndex_s, mouseScrolled, abs, rel);
     }
@@ -231,5 +231,5 @@
     {
         assert(device < handlers_.size());
-        if (handlers_[device] != NULL)
+        if (handlers_[device] != nullptr)
             INPUT_STATE_PUSH_CALL(device, axisMoved, device - firstJoyStickIndex_s, axis, value);
     }
Index: code/branches/cpp11_v2/src/libraries/core/input/KeyBinder.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/input/KeyBinder.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/input/KeyBinder.cc	(revision 10765)
@@ -53,6 +53,6 @@
         : deriveTime_(0.0f)
         , filename_(filename)
-        , configFile_(NULL)
-        , fallbackConfigFile_(NULL)
+        , configFile_(nullptr)
+        , fallbackConfigFile_(nullptr)
     {
         mouseRelative_[0] = 0;
@@ -170,5 +170,5 @@
 
         // load the bindings if required
-        if (configFile_ != NULL)
+        if (configFile_ != nullptr)
         {
             for (unsigned int iDev = oldValue; iDev < joySticks_.size(); ++iDev)
Index: code/branches/cpp11_v2/src/libraries/core/input/KeyBinder.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/input/KeyBinder.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/input/KeyBinder.h	(revision 10765)
@@ -159,5 +159,5 @@
         //! Name of the file used in this KeyBinder (constant!)
         const std::string filename_;
-        //! Config file used. NULL in case of KeyDetector. Also indicates whether we've already loaded.
+        //! Config file used. nullptr in case of KeyDetector. Also indicates whether we've already loaded.
         ConfigFile* configFile_;
         //! Config file from the data directory that only serves as fallback
Index: code/branches/cpp11_v2/src/libraries/core/input/KeyBinderManager.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/input/KeyBinderManager.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/input/KeyBinderManager.cc	(revision 10765)
@@ -56,5 +56,5 @@
 
     KeyBinderManager::KeyBinderManager()
-        : currentBinder_(NULL)
+        : currentBinder_(nullptr)
         , bDefaultFileLoaded_(true)
         , bBinding_(false)
Index: code/branches/cpp11_v2/src/libraries/core/input/KeyBinderManager.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/input/KeyBinderManager.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/input/KeyBinderManager.h	(revision 10765)
@@ -107,5 +107,5 @@
 
         // KeyBinder management
-        KeyBinder* currentBinder_;                   //! Currently selected KeyBinder (never NULL!)
+        KeyBinder* currentBinder_;                   //! Currently selected KeyBinder (never nullptr!)
         std::map<std::string, KeyBinder*> binders_;  //! All loaded KeyBinders
         bool bDefaultFileLoaded_;                    //! Tells whether the default one is loaded
Index: code/branches/cpp11_v2/src/libraries/core/input/KeyDetector.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/input/KeyDetector.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/input/KeyDetector.cc	(revision 10765)
@@ -62,5 +62,5 @@
     KeyDetector::~KeyDetector()
     {
-        inputState_->setHandler(NULL);
+        inputState_->setHandler(nullptr);
         InputManager::getInstance().destroyState("detector");
         ModifyConsoleCommand(__CC_KeyDetector_callback_name).resetFunction();
Index: code/branches/cpp11_v2/src/libraries/core/module/DynLib.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/module/DynLib.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/module/DynLib.cc	(revision 10765)
@@ -56,5 +56,5 @@
     {
         mName = name;
-        m_hInst = NULL;
+        m_hInst = nullptr;
     }
 
@@ -127,10 +127,10 @@
             FORMAT_MESSAGE_FROM_SYSTEM |
             FORMAT_MESSAGE_IGNORE_INSERTS,
-            NULL,
+            nullptr,
             GetLastError(),
             MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
             (LPTSTR) &lpMsgBuf,
             0,
-            NULL
+            nullptr
             );
         std::string ret = (char*)lpMsgBuf;
Index: code/branches/cpp11_v2/src/libraries/core/module/DynLib.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/module/DynLib.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/module/DynLib.h	(revision 10765)
@@ -45,5 +45,5 @@
 #if defined(ORXONOX_PLATFORM_WINDOWS)
 #    define DYNLIB_HANDLE hInstance
-#    define DYNLIB_LOAD( a ) LoadLibraryEx( a, NULL, LOAD_WITH_ALTERED_SEARCH_PATH )
+#    define DYNLIB_LOAD( a ) LoadLibraryEx( a, nullptr, LOAD_WITH_ALTERED_SEARCH_PATH )
 #    define DYNLIB_GETSYM( a, b ) GetProcAddress( a, b )
 #    define DYNLIB_UNLOAD( a ) !FreeLibrary( a )
@@ -104,5 +104,5 @@
                 the symbol.
             @par
-                If the function fails, the returned value is <b>NULL</b>.
+                If the function fails, the returned value is <b>nullptr</b>.
 
         */
Index: code/branches/cpp11_v2/src/libraries/core/module/ModuleInstance.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/module/ModuleInstance.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/module/ModuleInstance.cc	(revision 10765)
@@ -33,9 +33,9 @@
 namespace orxonox
 {
-    ModuleInstance* ModuleInstance::currentModuleInstance_s = NULL;
+    ModuleInstance* ModuleInstance::currentModuleInstance_s = nullptr;
 
     ModuleInstance::ModuleInstance(const std::string& libraryName)
         : libraryName_(libraryName)
-        , dynLib_(NULL)
+        , dynLib_(nullptr)
     {
     }
Index: code/branches/cpp11_v2/src/libraries/core/module/Plugin.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/module/Plugin.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/module/Plugin.cc	(revision 10765)
@@ -38,10 +38,10 @@
     {
         this->referenceCounter_ = 0;
-        this->moduleInstance_ = NULL;
+        this->moduleInstance_ = nullptr;
     }
 
     Plugin::~Plugin()
     {
-        if (this->moduleInstance_ != NULL)
+        if (this->moduleInstance_ != nullptr)
         {
             this->referenceCounter_ = 1; // force unloading
@@ -77,5 +77,5 @@
             Core::getInstance().unloadModule(this->moduleInstance_);
             delete this->moduleInstance_;
-            this->moduleInstance_ = NULL;
+            this->moduleInstance_ = nullptr;
         }
         else
Index: code/branches/cpp11_v2/src/libraries/core/module/PluginManager.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/module/PluginManager.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/module/PluginManager.cc	(revision 10765)
@@ -56,6 +56,6 @@
     PluginManager::~PluginManager()
     {
-        ModifyConsoleCommand("PluginManager", __CC_PluginManager_load_name).setObject(NULL);
-        ModifyConsoleCommand("PluginManager", __CC_PluginManager_unload_name).setObject(NULL);
+        ModifyConsoleCommand("PluginManager", __CC_PluginManager_load_name).setObject(nullptr);
+        ModifyConsoleCommand("PluginManager", __CC_PluginManager_unload_name).setObject(nullptr);
 
         for (std::map<std::string, PluginReference*>::iterator it = this->references_.begin(); it != this->references_.end(); ++it)
@@ -89,5 +89,5 @@
     {
         Plugin* plugin = this->plugins_[name];
-        if (plugin != NULL)
+        if (plugin != nullptr)
             plugin->load();
         else
@@ -98,5 +98,5 @@
     {
         Plugin* plugin = this->plugins_[name];
-        if (plugin != NULL)
+        if (plugin != nullptr)
             plugin->unload();
         else
@@ -109,5 +109,5 @@
     void PluginManager::loadPlugin(const std::string& name)
     {
-        if (this->references_[name] == NULL)
+        if (this->references_[name] == nullptr)
         {
             this->references_[name] = new PluginReference(name);
@@ -124,7 +124,7 @@
     {
         PluginReference* reference = this->references_[name];
-        if (reference != NULL)
+        if (reference != nullptr)
         {
-            this->references_[name] = NULL;
+            this->references_[name] = nullptr;
             delete reference;
         }
Index: code/branches/cpp11_v2/src/libraries/core/object/Destroyable.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/object/Destroyable.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/object/Destroyable.cc	(revision 10765)
@@ -66,5 +66,5 @@
     void Destroyable::destroy()
     {
-        assert(this); // Just in case someone tries to delete a NULL pointer
+        assert(this); // Just in case someone tries to delete a nullptr
         this->requestedDestruction_ = true;
         if (this->referenceCount_ == 0)
Index: code/branches/cpp11_v2/src/libraries/core/object/IteratorBase.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/object/IteratorBase.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/object/IteratorBase.h	(revision 10765)
@@ -58,5 +58,5 @@
                 @brief Constructor: Sets the element, whereon the iterator points, to the given element.
             */
-            inline IteratorBase(ObjectListElement<T>* element = NULL)
+            inline IteratorBase(ObjectListElement<T>* element = nullptr)
             {
                 this->element_ = element;
@@ -151,5 +151,5 @@
             inline operator bool() const
             {
-                return (this->element_ != NULL);
+                return (this->element_ != nullptr);
             }
 
@@ -208,5 +208,5 @@
                 }
                 else
-                    this->list_ = NULL;
+                    this->list_ = nullptr;
             }
 
Index: code/branches/cpp11_v2/src/libraries/core/object/StrongPtr.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/object/StrongPtr.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/object/StrongPtr.h	(revision 10765)
@@ -248,5 +248,5 @@
             }
 
-            /// Returns true if the wrapped pointer is NULL.
+            /// Returns true if the wrapped pointer is nullptr.
             inline bool operator!() const
             {
@@ -269,5 +269,5 @@
             }
 
-            /// Resets the strong pointer (equivalent to assigning a NULL pointer).
+            /// Resets the strong pointer (equivalent to assigning a nullptr).
             inline void reset()
             {
Index: code/branches/cpp11_v2/src/libraries/core/singleton/ScopedSingletonIncludes.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/singleton/ScopedSingletonIncludes.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/singleton/ScopedSingletonIncludes.h	(revision 10765)
@@ -71,5 +71,5 @@
 */
 #define ManageScopedSingleton(className, scope, allowedToFail) \
-    className* className::singletonPtr_s = NULL; \
+    className* className::singletonPtr_s = nullptr; \
     static ScopedSingletonWrapper& className##ScopedSingletonWrapper \
         = (new orxonox::SI_SSW(new ClassScopedSingletonWrapper<className, allowedToFail>(#className), scope))->getWrapper()
Index: code/branches/cpp11_v2/src/libraries/core/singleton/ScopedSingletonWrapper.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/singleton/ScopedSingletonWrapper.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/singleton/ScopedSingletonWrapper.h	(revision 10765)
@@ -91,5 +91,5 @@
         ClassScopedSingletonWrapper(const std::string& className)
             : ScopedSingletonWrapper(className)
-            , singletonPtr_(NULL)
+            , singletonPtr_(nullptr)
         {
         }
@@ -104,5 +104,5 @@
         void activated()
         {
-            assert(singletonPtr_ == NULL);
+            assert(singletonPtr_ == nullptr);
             singletonPtr_ = new T();
         }
@@ -111,7 +111,7 @@
         void deactivated()
         {
-            assert(singletonPtr_ != NULL);
+            assert(singletonPtr_ != nullptr);
             this->destroy(singletonPtr_);
-            singletonPtr_ = NULL;
+            singletonPtr_ = nullptr;
         }
 
@@ -146,5 +146,5 @@
         ClassScopedSingletonWrapper(const std::string& className)
             : ScopedSingletonWrapper(className)
-            , singletonPtr_(NULL)
+            , singletonPtr_(nullptr)
         {
         }
@@ -159,5 +159,5 @@
         void activated()
         {
-            assert(singletonPtr_ == NULL);
+            assert(singletonPtr_ == nullptr);
             try
                 { singletonPtr_ = new T(); }
@@ -171,8 +171,8 @@
         void deactivated()
         {
-            if (singletonPtr_ != NULL)
+            if (singletonPtr_ != nullptr)
             {
                 this->destroy(singletonPtr_);
-                singletonPtr_ = NULL;
+                singletonPtr_ = nullptr;
             }
         }
Index: code/branches/cpp11_v2/src/libraries/network/ClientConnection.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/ClientConnection.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/ClientConnection.cc	(revision 10765)
@@ -44,5 +44,5 @@
     Connection(NETWORK_PEER_ID_SERVER),
     established_(false),
-    server_(NULL)
+    server_(nullptr)
   {
     this->serverAddress_ = new ENetAddress();
@@ -72,9 +72,9 @@
 
     // create host
-    this->host_ = enet_host_create(NULL, NETWORK_CLIENT_MAX_CONNECTIONS, NETWORK_CHANNEL_COUNT, 0, 0);
+    this->host_ = enet_host_create(nullptr, NETWORK_CLIENT_MAX_CONNECTIONS, NETWORK_CHANNEL_COUNT, 0, 0);
     
-    if ( this->host_ == NULL )
+    if ( this->host_ == nullptr )
     {
-      orxout(internal_error, context::network) << "ClientConnection: host_ == NULL" << endl;
+      orxout(internal_error, context::network) << "ClientConnection: host_ == nullptr" << endl;
       // error handling
       return false;
@@ -93,7 +93,7 @@
 
     this->server_ = enet_host_connect(this->host_, serverAddress_, NETWORK_CHANNEL_COUNT, 0);
-    if ( this->server_==NULL )
+    if ( this->server_==nullptr )
     {
-      orxout(internal_error, context::network) << "ClientConnection: server_ == NULL" << endl;
+      orxout(internal_error, context::network) << "ClientConnection: server_ == nullptr" << endl;
       // error handling
       return false;
Index: code/branches/cpp11_v2/src/libraries/network/FunctionCall.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/FunctionCall.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/FunctionCall.cc	(revision 10765)
@@ -48,5 +48,5 @@
 bool FunctionCall::execute(){
   NetworkFunctionBase* fct = NetworkFunctionManager::getInstance().getFunctionByNetworkId( this->functionID_ );
-  assert( fct != NULL );
+  assert( fct != nullptr );
   assert( this->nrOfArguments_==this->arguments_.size() );
   switch(this->nrOfArguments_)
Index: code/branches/cpp11_v2/src/libraries/network/LANDiscoverable.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/LANDiscoverable.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/LANDiscoverable.cc	(revision 10765)
@@ -85,6 +85,6 @@
       assert( this->host_ == 0 );
       this->host_ = enet_host_create( &bindAddress, 10, 0, 0, 0 );
-      if ( this->host_ == NULL )
-          orxout(internal_error, context::network) << "LANDiscoverable: host_ == NULL" << endl;
+      if ( this->host_ == nullptr )
+          orxout(internal_error, context::network) << "LANDiscoverable: host_ == nullptr" << endl;
     }
     else
Index: code/branches/cpp11_v2/src/libraries/network/LANDiscovery.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/LANDiscovery.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/LANDiscovery.cc	(revision 10765)
@@ -42,12 +42,12 @@
   LANDiscovery::LANDiscovery()
   {
-    this->host_ = enet_host_create(NULL, 10, 0, 0, 0 );
-    if ( this->host_ == NULL )
-        orxout(internal_error, context::network) << "LANDiscovery: host_ == NULL" << endl;
+    this->host_ = enet_host_create(nullptr, 10, 0, 0, 0 );
+    if ( this->host_ == nullptr )
+        orxout(internal_error, context::network) << "LANDiscovery: host_ == nullptr" << endl;
   }
 
   LANDiscovery::~LANDiscovery()
   {
-    if (this->host_ != NULL)
+    if (this->host_ != nullptr)
       enet_host_destroy(this->host_);
   }
@@ -65,5 +65,5 @@
     address.host = ENET_HOST_BROADCAST;
     peer = enet_host_connect(this->host_, &address, 0, 0);
-    if (peer == NULL)
+    if (peer == nullptr)
         orxout(internal_error, context::network) << "Could not send LAN discovery to IPv4 Broadcast." << endl;
 
@@ -71,5 +71,5 @@
     enet_address_set_host(&address, "ff02::1"); // TODO: use a multicast group
     peer = enet_host_connect(this->host_, &address, 0, 0);
-    if (peer == NULL)
+    if (peer == nullptr)
         orxout(internal_error, context::network) << "Could not send LAN discovery to IPv6 Multicast." << endl;
 
Index: code/branches/cpp11_v2/src/libraries/network/MasterServer.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/MasterServer.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/MasterServer.cc	(revision 10765)
@@ -43,5 +43,5 @@
 
   /* forward declaration so the linker doesn't complain */
-  MasterServer *MasterServer::instance = NULL;
+  MasterServer *MasterServer::instance = nullptr;
 
   /* command: list servers */
@@ -345,5 +345,5 @@
     /***** ENTER MAIN LOOP *****/
     ENetEvent *event = (ENetEvent *)calloc(sizeof(ENetEvent), sizeof(char));
-    if( event == NULL )
+    if( event == nullptr )
     {
       orxout(user_error, context::master_server) << "Could not create ENetEvent structure, exiting." << endl;
Index: code/branches/cpp11_v2/src/libraries/network/MasterServerComm.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/MasterServerComm.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/MasterServerComm.cc	(revision 10765)
@@ -54,5 +54,5 @@
 
     /* initiate the client */
-    this->client = enet_host_create( NULL /* create a client host */,
+    this->client = enet_host_create( nullptr /* create a client host */,
         1,
         2, /* allow up 2 channels to be used, 0 and 1 */
@@ -61,5 +61,5 @@
 
     /* see if it worked */
-    if (this->client == NULL)
+    if (this->client == nullptr)
     { orxout(internal_error, context::master_server) << "An error occurred while trying to create an " 
         << "ENet client host." << endl;
@@ -85,5 +85,5 @@
     this->peer = enet_host_connect(this->client, &this->address, 2, 0);    
 
-    if( this->peer == NULL )
+    if( this->peer == nullptr )
     { orxout(internal_error, context::master_server) << "No available peers for initiating an ENet"
         << " connection." << endl;
@@ -157,5 +157,5 @@
 
     /* address buffer */
-    char *addrconv = NULL;
+    char *addrconv = nullptr;
     int retval = 0;
 
@@ -193,5 +193,5 @@
 
           /* call the supplied callback, if any. */
-          if( listener != NULL )
+          if( listener != nullptr )
             retval = listener->rhandler( addrconv, &(this->event) );
 
Index: code/branches/cpp11_v2/src/libraries/network/NetworkFunctionManager.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/NetworkFunctionManager.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/NetworkFunctionManager.cc	(revision 10765)
@@ -71,5 +71,5 @@
             return it->second;
         else
-            return NULL;
+            return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/libraries/network/PeerList.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/PeerList.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/PeerList.cc	(revision 10765)
@@ -41,5 +41,5 @@
   PeerList::addPeer( ENetPeer *toadd )
   { /* error correction */
-    if( toadd == NULL )
+    if( toadd == nullptr )
     { orxout(internal_error, context::master_server) << "PeerList::addPeer: empty peer given." << endl;
       return -1;
@@ -92,5 +92,5 @@
 
     /* not found */
-    return NULL;
+    return nullptr;
   }
 
Index: code/branches/cpp11_v2/src/libraries/network/Server.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/Server.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/Server.cc	(revision 10765)
@@ -244,5 +244,5 @@
   {
 //     ClientInformation *temp = ClientInformation::getBegin();
-//     if( temp == NULL )
+//     if( temp == nullptr )
       //no client connected
     if( this->clientIDs_.size()==0 )
@@ -255,5 +255,5 @@
     }
 //     orxout(verbose, context::network) << "sending DeleteObjects" << endl;
-//     while(temp != NULL){
+//     while(temp != nullptr){
 //       if( !(temp->getSynched()) )
 //       {
Index: code/branches/cpp11_v2/src/libraries/network/ServerConnection.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/ServerConnection.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/ServerConnection.cc	(revision 10765)
@@ -73,7 +73,7 @@
     this->host_ = enet_host_create(this->bindAddress_, NETWORK_MAX_CONNECTIONS, NETWORK_CHANNEL_COUNT, 0, 0);
     
-    if ( this->host_ == NULL )
+    if ( this->host_ == nullptr )
     {
-        orxout(internal_error, context::network) << "ServerConnection: host_ == NULL" << endl;
+        orxout(internal_error, context::network) << "ServerConnection: host_ == nullptr" << endl;
         return false;
     }
Index: code/branches/cpp11_v2/src/libraries/network/packet/ClassID.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/packet/ClassID.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/packet/ClassID.cc	(revision 10765)
@@ -58,5 +58,5 @@
   for(;it != IdentifierManager::getInstance().getIdentifierByStringMap().end();++it){
     id = it->second;
-    if(id == NULL || !id->hasFactory())
+    if(id == nullptr || !id->hasFactory())
       continue;
     const std::string& classname = id->getName();
@@ -144,5 +144,5 @@
     id=ClassByString( std::string((const char*)classname) );
     orxout(internal_info, context::packets) << "processing classid: " << networkID << " name: " << classname << " id: " << id << endl;
-    if(id==NULL){
+    if(id==nullptr){
       orxout(user_error, context::packets) << "Received a bad classname" << endl;
       abort();
Index: code/branches/cpp11_v2/src/libraries/network/packet/Gamestate.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/packet/Gamestate.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/packet/Gamestate.cc	(revision 10765)
@@ -608,5 +608,5 @@
 
   if(dest_length==0)
-    return NULL;
+    return nullptr;
 
   uint8_t *ndata = new uint8_t[dest_length*sizeof(uint8_t)+GamestateHeader::getSize()];
@@ -645,5 +645,5 @@
 
   if(dest_length==0)
-    return NULL;
+    return nullptr;
 
   uint8_t *ndata = new uint8_t[dest_length*sizeof(uint8_t)+GamestateHeader::getSize()];
Index: code/branches/cpp11_v2/src/libraries/network/packet/Packet.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/packet/Packet.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/packet/Packet.cc	(revision 10765)
@@ -122,5 +122,5 @@
   // Destroy the ENetPacket if necessary.
   // Note: For the case ENet used the callback to destroy the packet, we have already set
-  // enetPacket_ to NULL to avoid destroying it again.
+  // enetPacket_ to nullptr to avoid destroying it again.
   if (this->enetPacket_)
   {
Index: code/branches/cpp11_v2/src/libraries/network/synchronisable/Synchronisable.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/network/synchronisable/Synchronisable.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/network/synchronisable/Synchronisable.cc	(revision 10765)
@@ -105,9 +105,9 @@
   uint32_t Synchronisable::findContextID(Context* context)
   {
-      if (context == NULL)
+      if (context == nullptr)
           return OBJECTID_UNKNOWN;
 
       Synchronisable* synchronisableContext = orxonox_cast<Synchronisable*>(context);
-      if (synchronisableContext != NULL)
+      if (synchronisableContext != nullptr)
           return synchronisableContext->getObjectID();
       else
@@ -226,5 +226,5 @@
       return it1->second;
     // if the objects not in the map it should'nt exist at all anymore
-    return NULL;
+    return nullptr;
   }
 
Index: code/branches/cpp11_v2/src/libraries/tools/ResourceCollection.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/tools/ResourceCollection.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/tools/ResourceCollection.cc	(revision 10765)
@@ -93,5 +93,5 @@
     {
         if (index >= resourceLocations_.size())
-            return NULL;
+            return nullptr;
         else
             return resourceLocations_[index];
Index: code/branches/cpp11_v2/src/libraries/tools/Shader.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/tools/Shader.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/tools/Shader.cc	(revision 10765)
@@ -109,5 +109,5 @@
     {
         // For the moment, we get the viewport always from the graphics manager
-        // TODO: Try to support multiple viewports - note however that scenemanager_->getCurrentViewport() returns NULL
+        // TODO: Try to support multiple viewports - note however that scenemanager_->getCurrentViewport() returns nullptr
         //       after switching to a camera in a different scene (only for the first time this scene is displayed though)
         this->changedCompositorName(GraphicsManager::getInstance().getViewport());
Index: code/branches/cpp11_v2/src/libraries/util/Clipboard.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/Clipboard.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/Clipboard.cc	(revision 10765)
@@ -93,5 +93,5 @@
             {
                 HANDLE hData = GetClipboardData(CF_TEXT);
-                if (hData == NULL)
+                if (hData == nullptr)
                     return "";
                 std::string output(static_cast<char*>(GlobalLock(hData)));
Index: code/branches/cpp11_v2/src/libraries/util/DestructionHelper.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/DestructionHelper.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/DestructionHelper.h	(revision 10765)
@@ -36,5 +36,5 @@
     /** Deletes an object and resets the pointer
     @param object
-        Pointer to an object. Handing over NULL is safe.
+        Pointer to an object. Handing over nullptr is safe.
     */
     template <class T>
@@ -42,5 +42,5 @@
     {
         delete *object;
-        *object = NULL;
+        *object = nullptr;
     }
 
Index: code/branches/cpp11_v2/src/libraries/util/SharedPtr.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/SharedPtr.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/SharedPtr.h	(revision 10765)
@@ -215,5 +215,5 @@
 
         public:
-            /// Default constructor, the pointer is set to NULL.
+            /// Default constructor, the pointer is set to nullptr.
             inline SharedPtr() : pointer_(0), counter_(0)
             {
@@ -310,5 +310,5 @@
             }
 
-            /// Returns true if the pointer is not NULL.
+            /// Returns true if the pointer is not nullptr.
             inline operator bool() const
             {
Index: code/branches/cpp11_v2/src/libraries/util/SignalHandler.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/SignalHandler.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/SignalHandler.h	(revision 10765)
@@ -113,5 +113,5 @@
             void doCatch(const std::string& appName, const std::string& filename);
 
-            static std::string getStackTrace(PEXCEPTION_POINTERS pExceptionInfo = NULL);
+            static std::string getStackTrace(PEXCEPTION_POINTERS pExceptionInfo = nullptr);
             static std::string getExceptionType(PEXCEPTION_POINTERS pExceptionInfo);
 
Index: code/branches/cpp11_v2/src/libraries/util/Singleton.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/Singleton.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/Singleton.h	(revision 10765)
@@ -66,5 +66,5 @@
     And don't forget to initialize the static singleton pointer in the source (*.cc) %file:
     @code
-    TestSingleton* TestSingleton::singletonPtr_s = NULL;
+    TestSingleton* TestSingleton::singletonPtr_s = nullptr;
     @endcode
 
@@ -118,5 +118,5 @@
         static T& getInstance()
         {
-            OrxVerify(T::singletonPtr_s != NULL, "T=" << typeid(T).name());
+            OrxVerify(T::singletonPtr_s != nullptr, "T=" << typeid(T).name());
             return *T::singletonPtr_s;
         }
@@ -125,5 +125,5 @@
         static bool exists()
         {
-            return (T::singletonPtr_s != NULL);
+            return (T::singletonPtr_s != nullptr);
         }
 
@@ -132,5 +132,5 @@
         Singleton()
         {
-            OrxVerify(T::singletonPtr_s == NULL, "T=" << typeid(T).name());
+            OrxVerify(T::singletonPtr_s == nullptr, "T=" << typeid(T).name());
             T::singletonPtr_s = static_cast<T*>(this);
         }
@@ -139,6 +139,6 @@
         virtual ~Singleton()
         {
-            OrxVerify(T::singletonPtr_s != NULL, "T=" << typeid(T).name());
-            T::singletonPtr_s = NULL;
+            OrxVerify(T::singletonPtr_s != nullptr, "T=" << typeid(T).name());
+            T::singletonPtr_s = nullptr;
         }
 
Index: code/branches/cpp11_v2/src/libraries/util/SmallObjectAllocator.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/SmallObjectAllocator.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/SmallObjectAllocator.cc	(revision 10765)
@@ -97,5 +97,5 @@
                 setNext(block + i * this->chunkSize_, block + (i + 1) * this->chunkSize_);
 
-            // the next_ pointer of the last chunk must point to NULL
+            // the next_ pointer of the last chunk must point to nullptr
             setNext(block + (this->numChunksPerBlock_ - 1) * this->chunkSize_, 0);
 

Index: code/branches/cpp11_v2/src/libraries/core/command/Functor.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/command/Functor.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/command/Functor.h	(revision 10765)
@@ -215,5 +215,5 @@
             virtual void* getRawObjectPointer() const = 0;
 
             /// Enables or disables the safe mode which causes the functor to change the object pointer to NULL if the object is deleted (only member functors).
             virtual void setSafeMode(bool bSafeMode) = 0;
 
@@ -245,5 +245,5 @@
             virtual ~FunctorMember() { if (this->bSafeMode_) { this->unregisterObject(this->object_); } }
 
             /// Calls the function-pointer with up to five arguments and an object. In case of a static-function, the object can be NULL. @return Returns the return-value of the function (if any; MultiType::Null otherwise)
             virtual MultiType operator()(O* object, const MultiType& param1 = MultiType::Null, const MultiType& param2 = MultiType::Null, const MultiType& param3 = MultiType::Null, const MultiType& param4 = MultiType::Null, const MultiType& param5 = MultiType::Null) = 0;
 
@@ -312,6 +312,6 @@
                 { this->object_ = 0; }
 
-            O* object_;     ///< The stored object-pointer, used to execute a member-function (or NULL for static functions)
-            bool bSafeMode_; ///< If true, the functor is in safe mode and registers itself as listener at the object and changes the pointer to NULL if the object is deleted
+            O* object_;     ///< The stored object-pointer, used to execute a member-function (or nullptr for static functions)
+            bool bSafeMode_; ///< If true, the functor is in safe mode and registers itself as listener at the object and changes the pointer to nullptr if the object is deleted
     };
 
@@ -324,5 +324,5 @@
             FunctorMember(void* object = 0) {}
 
             /// Calls the function-pointer with up to five arguments and an object. In case of a static-function, the object can be NULL. @return Returns the return-value of the function (if any; MultiType::Null otherwise)
             virtual MultiType operator()(void* object, const MultiType& param1 = MultiType::Null, const MultiType& param2 = MultiType::Null, const MultiType& param3 = MultiType::Null, const MultiType& param4 = MultiType::Null, const MultiType& param5 = MultiType::Null) = 0;
 
@@ -215,5 +215,5 @@
             virtual void* getRawObjectPointer() const = 0;
 
-            /// Enables or disables the safe mode which causes the functor to change the object pointer to NULL if the object is deleted (only member functors).
+            /// Enables or disables the safe mode which causes the functor to change the object pointer to nullptr if the object is deleted (only member functors).
             virtual void setSafeMode(bool bSafeMode) = 0;
 
@@ -245,5 +245,5 @@
             virtual ~FunctorMember() { if (this->bSafeMode_) { this->unregisterObject(this->object_); } }
 
-            /// Calls the function-pointer with up to five arguments and an object. In case of a static-function, the object can be NULL. @return Returns the return-value of the function (if any; MultiType::Null otherwise)
+            /// Calls the function-pointer with up to five arguments and an object. In case of a static-function, the object can be nullptr. @return Returns the return-value of the function (if any; MultiType::Null otherwise)
             virtual MultiType operator()(O* object, const MultiType& param1 = MultiType::Null, const MultiType& param2 = MultiType::Null, const MultiType& param3 = MultiType::Null, const MultiType& param4 = MultiType::Null, const MultiType& param5 = MultiType::Null) = 0;
 
@@ -324,5 +324,5 @@
             FunctorMember(void* object = 0) {}
 
-            /// Calls the function-pointer with up to five arguments and an object. In case of a static-function, the object can be NULL. @return Returns the return-value of the function (if any; MultiType::Null otherwise)
+            /// Calls the function-pointer with up to five arguments and an object. In case of a static-function, the object can be nullptr. @return Returns the return-value of the function (if any; MultiType::Null otherwise)
             virtual MultiType operator()(void* object, const MultiType& param1 = MultiType::Null, const MultiType& param2 = MultiType::Null, const MultiType& param3 = MultiType::Null, const MultiType& param4 = MultiType::Null, const MultiType& param5 = MultiType::Null) = 0;
 
Index: code/branches/cpp11_v2/src/libraries/core/config/ConfigFileManager.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/config/ConfigFileManager.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/config/ConfigFileManager.cc	(revision 10765)
@@ -44,8 +44,8 @@
     ConfigFileManager* ConfigFileManager::singletonPtr_s = 0;
 
     /// Constructor: Initializes the array of config files with NULL.
     ConfigFileManager::ConfigFileManager()
     {
-        this->configFiles_.assign(NULL);
+        this->configFiles_.assign(nullptr);
     }
 
@@ -44,8 +44,8 @@
     ConfigFileManager* ConfigFileManager::singletonPtr_s = 0;
 
-    /// Constructor: Initializes the array of config files with NULL.
+    /// Constructor: Initializes the array of config files with nullptr.
     ConfigFileManager::ConfigFileManager()
     {
Index: code/branches/cpp11_v2/src/libraries/core/object/Context.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/object/Context.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/object/Context.cc	(revision 10765)
@@ -46,11 +46,11 @@
         static size_t count = 0;
         // the first time this is called, ++count returns 1 and the context is created
         // the second time this is called, ++count returns 2 and NULL is returned because we're in the constructor of the context itself
         // for each future call the context (now completely created) is returned
         if (++count == 2)
-            return NULL;
+            return nullptr;
         else
         {
-            static Context context(NULL);
+            static Context context(nullptr);
             return &context;
         }
@@ -82,10 +82,10 @@
     {
         delete Context::rootContext_s;
-        Context::rootContext_s = NULL;
+        Context::rootContext_s = nullptr;
     }
 
     /*static*/ Context* Context::getRootContext()
     {
-        OrxVerify(Context::rootContext_s != NULL, "Root Context is undefined");
+        OrxVerify(Context::rootContext_s != nullptr, "Root Context is undefined");
         return Context::rootContext_s;
     }
@@ -105,5 +105,5 @@
         ObjectListBase* objectList = this->getObjectList(identifier);
         delete objectList;
-        this->objectLists_[identifier->getClassID()] = NULL;
+        this->objectLists_[identifier->getClassID()] = nullptr;
     }
 }
@@ -46,11 +46,11 @@
         static size_t count = 0;
         // the first time this is called, ++count returns 1 and the context is created
-        // the second time this is called, ++count returns 2 and NULL is returned because we're in the constructor of the context itself
+        // the second time this is called, ++count returns 2 and nullptr is returned because we're in the constructor of the context itself
         // for each future call the context (now completely created) is returned
         if (++count == 2)
Index: code/branches/cpp11_v2/src/libraries/core/object/WeakPtr.h
===================================================================
--- code/branches/cpp11_v2/src/libraries/core/object/WeakPtr.h	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/core/object/WeakPtr.h	(revision 10765)
@@ -37,5 +37,5 @@
 
     A WeakPtr wraps a pointer to an object. If the object gets deleted, the WeakPtr becomes
-    NULL. This can be used to store pointers to objects without knowing when they will be
+    nullptr. This can be used to store pointers to objects without knowing when they will be
     destroyed.
 
@@ -50,10 +50,10 @@
     WeakPtr<MyClass> pointer = object;                  // create a WeakPtr and assign the object
 
-    if (pointer)                                        // checks if pointer is not NULL (which is true)
+    if (pointer)                                        // checks if pointer is not nullptr (which is true)
         pointer->someFunction();                        // calls MyClass::someFunction()
 
     object->destroy();                                  // calls destroy() which deletes the object
 
-    if (pointer)                                        // checks if pointer is not NULL (which is now false)
+    if (pointer)                                        // checks if pointer is not nullptr (which is now false)
         pointer->someFunction();                        // this will not be executed
     @endcode
@@ -91,5 +91,5 @@
 {
     /**
-        @brief WeakPtr wraps a pointer to an object, which becomes NULL if the object is deleted.
+        @brief WeakPtr wraps a pointer to an object, which becomes nullptr if the object is deleted.
 
         @see See @ref WeakPtrExample "this description" for more information and an example.
@@ -183,5 +183,5 @@
             }
 
             /// Returns true if the wrapped pointer is NULL.
             inline bool operator!() const
             {
@@ -210,5 +210,5 @@
             }
 
             /// Resets the weak pointer (equivalent to assigning a NULL pointer).
             inline void reset()
             {
@@ -183,5 +183,5 @@
             }
 
-            /// Returns true if the wrapped pointer is NULL.
+            /// Returns true if the wrapped pointer is nullptr.
             inline bool operator!() const
             {
@@ -210,5 +210,5 @@
             }
 
-            /// Resets the weak pointer (equivalent to assigning a NULL pointer).
+            /// Resets the weak pointer (equivalent to assigning a nullptr).
             inline void reset()
             {
Index: code/branches/cpp11_v2/src/libraries/util/SignalHandler.cc
===================================================================
--- code/branches/cpp11_v2/src/libraries/util/SignalHandler.cc	(revision 10745)
+++ code/branches/cpp11_v2/src/libraries/util/SignalHandler.cc	(revision 10765)
@@ -44,5 +44,5 @@
 namespace orxonox
 {
-    SignalHandler* SignalHandler::singletonPtr_s = NULL;
+    SignalHandler* SignalHandler::singletonPtr_s = nullptr;
 }
 
@@ -175,5 +175,5 @@
         dup2( gdbErr[1], STDERR_FILENO );
 
-        execlp( "sh", "sh", "-c", "gdb", static_cast<void*>(NULL));
+        execlp( "sh", "sh", "-c", "gdb", static_cast<void*>(nullptr));
       }
 
@@ -186,5 +186,5 @@
         perror("pipe failed!\n");
         kill( gdbPid, SIGTERM );
-        waitpid( gdbPid, NULL, 0 );
+        waitpid( gdbPid, nullptr, 0 );
         exit(EXIT_FAILURE);
       }
@@ -196,5 +196,5 @@
         perror("fork failed!\n");
         kill( gdbPid, SIGTERM );
-        waitpid( gdbPid, NULL, 0 );
+        waitpid( gdbPid, nullptr, 0 );
         exit(EXIT_FAILURE);
       }
@@ -297,6 +297,6 @@
 
 
-      waitpid( sigPid, NULL, 0 );
-      waitpid( gdbPid, NULL, 0 );
+      waitpid( sigPid, nullptr, 0 );
+      waitpid( gdbPid, nullptr, 0 );
 
       int wsRemoved = 0;
@@ -312,5 +312,5 @@
         bt.erase(0, 1);
 
-      time_t now = time(NULL);
+      time_t now = time(nullptr);
 
       std::string timeString =
@@ -388,5 +388,5 @@
     SignalHandler::SignalHandler()
     {
-        this->prevExceptionFilter_ = NULL;
+        this->prevExceptionFilter_ = nullptr;
     }
 
@@ -394,9 +394,9 @@
     SignalHandler::~SignalHandler()
     {
-        if (this->prevExceptionFilter_ != NULL)
+        if (this->prevExceptionFilter_ != nullptr)
         {
             // Remove the unhandled exception filter function
             SetUnhandledExceptionFilter(this->prevExceptionFilter_);
-            this->prevExceptionFilter_ = NULL;
+            this->prevExceptionFilter_ = nullptr;
         }
     }
@@ -408,7 +408,7 @@
 
         // don't register twice
-        assert(this->prevExceptionFilter_ == NULL);
-
-        if (this->prevExceptionFilter_ == NULL)
+        assert(this->prevExceptionFilter_ == nullptr);
+
+        if (this->prevExceptionFilter_ == nullptr)
         {
             // Install the unhandled exception filter function
@@ -441,5 +441,5 @@
             std::ofstream crashlog(SignalHandler::getInstance().filename_.c_str());
 
-            time_t now = time(NULL);
+            time_t now = time(nullptr);
 
             crashlog << "=======================================================" << endl;
@@ -480,5 +480,5 @@
     }
 
     /// Returns the stack trace for either the current function, or, if @a pExceptionInfo is not NULL, for the given exception context.
     /* static */ std::string SignalHandler::getStackTrace(PEXCEPTION_POINTERS pExceptionInfo)
     {
@@ -625,5 +625,5 @@
 #ifdef ORXONOX_COMPILER_GCC
                 int status;
-                char* demangled = __cxxabiv1::__cxa_demangle(symbol->Name, NULL, NULL, &status);
+                char* demangled = __cxxabiv1::__cxa_demangle(symbol->Name, nullptr, nullptr, &status);
                 if (demangled)
                 {
@@ -684,5 +684,5 @@
         HMODULE hModule;
 
-        std::string output = (GetModuleFileName(NULL, szModule, MAX_PATH) ? SignalHandler::getModuleName(szModule) : "Application");
+        std::string output = (GetModuleFileName(nullptr, szModule, MAX_PATH) ? SignalHandler::getModuleName(szModule) : "Application");
         output += " caused ";
 
@@ -480,5 +480,5 @@
     }
 
-    /// Returns the stack trace for either the current function, or, if @a pExceptionInfo is not NULL, for the given exception context.
+    /// Returns the stack trace for either the current function, or, if @a pExceptionInfo is not nullptr, for the given exception context.
     /* static */ std::string SignalHandler::getStackTrace(PEXCEPTION_POINTERS pExceptionInfo)
     {